==> open-xchange-documents-backend_7.6.3.orig.tar.bz2: open-xchange-documents-backend-7.6.3/com.openexchange.office.docx4j/src/xlsx4j/java/org/xlsx4j/sml/CTTableStyles.java <==
/*
 *  Copyright 2010-2013, Plutext Pty Ltd.
 *
 *  This file is part of xlsx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.

    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

 */
package org.xlsx4j.sml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_TableStyles complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="CT_TableStyles">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="tableStyle" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_TableStyle" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="count" type="{http://www.w3.org/2001/XMLSchema}unsignedInt" />
 *       &lt;attribute name="defaultTableStyle" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="defaultPivotStyle" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 *
 *
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_TableStyles", propOrder = {
    "tableStyle"
})
public class CTTableStyles implements Child
{

    protected List<CTTableStyle> tableStyle;
    @XmlAttribute(name = "count")
    @XmlSchemaType(name = "unsignedInt")
    protected Long count;
    @XmlAttribute(name = "defaultTableStyle")
    protected String defaultTableStyle;
    @XmlAttribute(name = "defaultPivotStyle")
    protected String defaultPivotStyle;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the tableStyle property.
     *
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the tableStyle property.
     *
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTableStyle().add(newItem);
     * </pre>
     *
     *
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTTableStyle }
     *
     *
     */
    public List<CTTableStyle> getTableStyle() {
        if (tableStyle == null) {
            tableStyle = new ArrayList<CTTableStyle>();
        }
        return this.tableStyle;
    }

    /**
     * Gets the value of the defaultTableStyle property.
     *
     * @return
     *     possible object is
     *     {@link String }
     *
     */
    public String getDefaultTableStyle() {
        return defaultTableStyle;
    }

    /**
     * Sets the value of the defaultTableStyle property.
     *
     * @param value
     *     allowed object is
     *     {@link String }
     *
     */
    public void setDefaultTableStyle(String value) {
        this.defaultTableStyle = value;
    }

    /**
     * Gets the value of the defaultPivotStyle property.
     *
     * @return
     *     possible object is
     *     {@link String }
     *
     */
    public String getDefaultPivotStyle() {
        return defaultPivotStyle;
    }

    /**
     * Sets the value of the defaultPivotStyle property.
     *
     * @param value
     *     allowed object is
     *     {@link String }
     *
     */
    public void setDefaultPivotStyle(String value) {
        this.defaultPivotStyle = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     *
     * @return
     *     The parent object.
     */
    @Override
    public Object getParent() {
        return this.parent;
    }

    @Override
    public void setParent(Object parent) {
        this.parent = parent;
    }

    @SuppressWarnings("unused")
    public void beforeMarshal(Marshaller marshaller) {
        this.count = tableStyle!=null?(long)tableStyle.size():0;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     *
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object _parent) {
        setParent(_parent);
    }

}

==> open-xchange-documents-backend_7.10.6.orig.tar.bz2: open-xchange-documents-backend-7.10.6/com.openexchange.office.docx4j/src/xlsx4j/java/org/xlsx4j/sml/CTTableStyles.java <==
/*
 *  Copyright 2010-2013, Plutext Pty Ltd.
 *
 *  This file is part of xlsx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.

    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

 */
package org.xlsx4j.sml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.Marshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;

/**
 * <p>Java class for CT_TableStyles complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="CT_TableStyles">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="tableStyle" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_TableStyle" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="count" type="{http://www.w3.org/2001/XMLSchema}unsignedInt" />
 *       &lt;attribute name="defaultTableStyle" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="defaultPivotStyle" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 *
 *
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_TableStyles", propOrder = {
    "tableStyle"
})
public class CTTableStyles
{
    protected List<CTTableStyle> tableStyle;
    @XmlAttribute(name = "count")
    @XmlSchemaType(name = "unsignedInt")
    protected Long count;
    @XmlAttribute(name = "defaultTableStyle")
    protected String defaultTableStyle;
    @XmlAttribute(name = "defaultPivotStyle")
    protected String defaultPivotStyle;

    /**
     * Gets the value of the tableStyle property.
     *
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the tableStyle property.
     *
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTableStyle().add(newItem);
     * </pre>
     *
     *
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTTableStyle }
     *
     *
     */
    public List<CTTableStyle> getTableStyle() {
        if (tableStyle == null) {
            tableStyle = new ArrayList<CTTableStyle>();
        }
        return this.tableStyle;
    }

    /**
     * Gets the value of the defaultTableStyle property.
     *
     * @return
     *     possible object is
     *     {@link String }
     *
     */
    public String getDefaultTableStyle() {
        return defaultTableStyle;
    }

    /**
     * Sets the value of the defaultTableStyle property.
     *
     * @param value
     *     allowed object is
     *     {@link String }
     *
     */
    public void setDefaultTableStyle(String value) {
        this.defaultTableStyle = value;
    }

    /**
     * Gets the value of the defaultPivotStyle property.
     *
     * @return
     *     possible object is
     *     {@link String }
     *
     */
    public String getDefaultPivotStyle() {
        return defaultPivotStyle;
    }

    /**
     * Sets the value of the defaultPivotStyle property.
     *
     * @param value
     *     allowed object is
     *     {@link String }
     *
     */
    public void setDefaultPivotStyle(String value) {
        this.defaultPivotStyle = value;
    }

    public void beforeMarshal(Marshaller marshaller) {
        this.count = tableStyle!=null?(long)tableStyle.size():0;
    }
}
